module ShotClock (

// ShotClock description...

	// Inputs
	I$Clock,	// Master clock
	I$Reset,	// Master reset, active high
	I$Run_,		// RUN, active low

	// Outputs
	O$Buzzer_,	// BUZZER, active low
	O$LED	// Seven-segment display, active high

);

// Port modes
input I$Clock;	// Master clock
input I$Reset;	// Master reset, active high
input I$Run_;		// RUN, active low

output O$Buzzer_;	// BUZZER, active low
output [6:0] O$LED;	// Seven-segment display, active high

// Registered variables
reg Run_Synced;

// Wire variables
wire CountEqualsZero;
wire EnableCounter;
wire Buzzer;


// Invert logic state of buzzer signal
assign O$Buzzer_ = ~Buzzer;

// Synchronize the async inputs
always @ (posedge I$Clock or posedge I$Reset)
	if (I$Reset==1)
		Run_Synced <= 0;
	else
		Run_Synced <= ~I$Run_;


// Instantiate the control unit
ShotClock_CU U1 (
	// Inputs
	.I$Clock(I$Clock),	// Master clock
	.I$Reset(I$Reset),	// Master reset, active high
	.I$Run(Run_Synced),		// RUN, active high
	.I$CountEqualsZero(CountEqualsZero),	// Indicates counter has
						// reached zero, active high

	// Outputs
	.O$Buzzer(Buzzer),	// BUZZER, active high
	.O$EnableCounter(EnableCounter)	// Enables count-down counter
);

// Instantiate the data unit
ShotClock_DU U2 (
	// Inputs
	.I$Clock(I$Clock),	// Master clock
	.I$Reset(I$Reset),	// Master reset, active high
	.I$EnableCounter(EnableCounter),		// RUN, active high

	// Outputs
	.O$CountEqualsZero(CountEqualsZero),	// BUZZER, active high
	.O$LED(O$LED)	// Enables count-down counter
);

endmodule

 