// Testbench for "Shot Clock" control unit

`timescale 1ns / 100 ps

module ShotClock_CU_TB;

reg I$Clock,I$Reset,I$Run,I$CountEqualsZero;
wire O$Buzzer,O$EnableCounter;

// Instantiate the device under test (DUT)
ShotClock_CU U1 (
	// Inputs
	.I$Clock(I$Clock),	// Master clock
	.I$Reset(I$Reset),	// Master reset, active high
	.I$Run(I$Run),		// RUN, active high
	.I$CountEqualsZero(I$CountEqualsZero),	// Indicates counter has
						// reached zero, active high

	// Outputs
	.O$Buzzer(O$Buzzer),	// BUZZER, active high
	.O$EnableCounter(O$EnableCounter)	// Enables count-down counter
);

// Input stimulus definitions

always
	#0.5 I$Clock = ~I$Clock;

initial begin
	// Initial values
	I$Clock = 0;
	I$Reset = 0;
	I$Run = 0;
	I$CountEqualsZero = 0;

	#1 

	// Apply master reset pulse
	I$Reset = 1;
	#1
	I$Reset = 0;
	#2

	// Apply RUN input
	I$Run = 1;
	#3

	// Disable RUN input
	I$Run = 0;
	#3

	// Enable RUN input
	I$Run = 1;
	#3

	// Enable CountEqualsZero
	I$CountEqualsZero = 1;
	#3

	I$Run = 0;
	#3

	I$CountEqualsZero = 0;
	#3

	I$Reset=1;
	#1
	I$Reset=0;
	#1



	// Simulation is complete
	$finish;
end

endmodule
