module ShotClock_DU (

// ShotClock Data Unit

	// Inputs
	I$Clock,	// Master clock
	I$Reset,	// Master reset, active high
	I$EnableCounter,	// Enables count-down counter

	// Outputs
	O$LED,	// seven-segment LED, active high
	O$CountEqualsZero	// Indicates counter has
						// reached zero, active high

);

// Port modes
input I$Clock,I$Reset,I$EnableCounter;
output O$CountEqualsZero;
output [6:0] O$LED;	// O$LED[6] -> segment a


// Registered variables
reg O$CountEqualsZero;
reg [6:0] O$LED;	// O$LED[6] -> segment a
reg [3:0] Count;

reg [25:0] ClkDivCount;
reg ClockSec;
//parameter MaxCount = 26'd40_000_000;	// 40-MHz clock
parameter MaxCount = 26'd9;	// 10-Hz clock (for simulation)


// Clock
always @ (posedge I$Clock or posedge I$Reset)
	if (I$Reset == 1) begin
		ClkDivCount <= 0;
		ClockSec <= 0;
	end
	else begin
		ClkDivCount <= (ClkDivCount == MaxCount) ? 0 :
			ClkDivCount + 1;
		ClockSec <= (ClkDivCount == MaxCount) ? 1 : 0;
	end
	

// Down counter
always @ (posedge ClockSec or posedge I$Reset)
	if (I$Reset == 1)
		Count <= 4'hF;
	else
		Count <= (I$EnableCounter) ? Count-1: Count;

// Comparator
always @ (Count)
	O$CountEqualsZero <= (Count==0) ? 1 : 0;

// LED driver
always @ (Count)
   case (Count)
      //   : LED segment abcdefg
      4'h0 : O$LED <= 7'b1111110;	// 0
      4'h1 : O$LED <= 7'b0110000;	// 1
      4'h2 : O$LED <= 7'b1101101;	// 2
      4'h3 : O$LED <= 7'b1111001;	// 3
      4'h4 : O$LED <= 7'b0110011;	// 4
      4'h5 : O$LED <= 7'b1011011;	// 5
      4'h6 : O$LED <= 7'b1011111;	// 6
      4'h7 : O$LED <= 7'b1110000;	// 7
      4'h8 : O$LED <= 7'b1111111;	// 8
      4'h9 : O$LED <= 7'b1111011;	// 9
      4'hA : O$LED <= 7'b1110111;	// A
      4'hB : O$LED <= 7'b0011111;	// b
      4'hC : O$LED <= 7'b1001110;	// C
      4'hD : O$LED <= 7'b0111101;	// d
      4'hE : O$LED <= 7'b1001111;	// E
      4'hF : O$LED <= 7'b1000111;	// F

      default : O$LED <= 7'b0000000;	// blank
   endcase



endmodule
